@@ -1,6 +1,6 @@
-/*  xfce4
+/*  $Id: pager.c,v 1.16 2004/11/18 21:37:25 jasper Exp $
  *
- *  Copyright (C) 2002 Jasper Huijsmans(huysmans@users.sourceforge.net)
+ *  Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 #include <math.h>
 
-#include <libxfce4util/i18n.h>
+#include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
 #include <panel/xfce.h>
@@ -55,6 +55,7 @@ typedef struct
 
     /* graphical pager */
     GtkWidget *netk_pager;
+    int rows;
 
     /* callback(s) we have to save for reorientation */
     GList *callbacks;
@@ -104,7 +105,6 @@ create_netk_pager (NetkScreen * screen)
 	GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL;
 
     pager = netk_pager_new (screen);
-    netk_pager_set_n_rows (NETK_PAGER (pager), 1);
     netk_pager_set_orientation (NETK_PAGER (pager), gor);
     gtk_widget_show (pager);
 
@@ -133,11 +133,14 @@ static void
 pager_set_orientation (Control * control, int orientation)
 {
     t_pager *pager;
+    GtkOrientation gor = (orientation == VERTICAL) ?
+	GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL;
 
     pager = control->data;
 
-    arrange_pager (pager);
-    pager_set_size (control, settings.size);
+    netk_pager_set_orientation (NETK_PAGER (pager->netk_pager), gor);
+
+    netk_pager_update_size (pager->netk_pager, pager->screen);
 }
 
 /*  creation, destruction and configuration 
@@ -164,9 +167,10 @@ arrange_pager (t_pager * pager)
     GList *li;
 
     if (pager->netk_pager)
-	gtk_widget_destroy(pager->netk_pager);
-    
+	gtk_widget_destroy (pager->netk_pager);
+
     pager->netk_pager = create_netk_pager (pager->screen);
+    netk_pager_set_n_rows (NETK_PAGER (pager->netk_pager), pager->rows);
 
     /* packing the widgets */
     gtk_container_add (GTK_CONTAINER (pager->base), pager->netk_pager);
@@ -203,8 +207,10 @@ pager_new (NetkScreen * screen)
 
     pager->screen = screen;
 
-    pager->base = gtk_alignment_new (0.5, 0.5, 0, 0); 
-    gtk_widget_show (pager->base); 
+    pager->base = gtk_alignment_new (0.5, 0.5, 0, 0);
+    gtk_widget_show (pager->base);
+
+    pager->rows = 1;
 
     /* this creates all widgets */
     arrange_pager (pager);
@@ -239,6 +245,100 @@ pager_free (Control * control)
     g_free (pager);
 }
 
+/* configuration */
+
+static void
+pager_read_config (Control * control, xmlNodePtr node)
+{
+    xmlChar *value;
+    int n, max;
+    t_pager *pager = control->data;
+
+    value = xmlGetProp (node, (const xmlChar *) "rows");
+
+    max = netk_screen_get_workspace_count (pager->screen);
+
+    if (value)
+    {
+	n = strtol (value, NULL, 0);
+	g_free (value);
+
+	if (n > 0 && n <= max)
+	{
+	    netk_pager_set_n_rows (NETK_PAGER (pager->netk_pager), n);
+	    pager->rows = n;
+	}
+    }
+}
+
+static void
+pager_write_config (Control * control, xmlNodePtr node)
+{
+    char prop[3];
+    t_pager *pager = control->data;
+
+    sprintf (prop, "%d", pager->rows);
+
+    xmlSetProp (node, (const xmlChar *) "rows", prop);
+}
+
+/* property dialog */
+static void
+rows_changed (GtkSpinButton * spin, t_pager * pager)
+{
+    int rows = gtk_spin_button_get_value_as_int (spin);
+
+    if (rows != pager->rows)
+    {
+	pager->rows = rows;
+
+	netk_pager_set_n_rows (NETK_PAGER (pager->netk_pager), pager->rows);
+    }
+}
+
+static void
+pager_create_options (Control * control, GtkContainer * container,
+		      GtkWidget * close)
+{
+    GtkWidget *hbox, *label, *spin;
+    int max;
+    t_pager *pager = control->data;
+
+    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+
+    hbox = gtk_hbox_new (FALSE, 6);
+    gtk_widget_show (hbox);
+    gtk_container_add (container, hbox);
+
+    if (settings.orientation == HORIZONTAL)
+	label = gtk_label_new (_("Number of rows:"));
+    else
+	label = gtk_label_new (_("Number of columns:"));
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+    max = netk_screen_get_workspace_count (pager->screen);
+
+    if (max > 1)
+    {
+        spin = gtk_spin_button_new_with_range (1, max, 1);
+        gtk_widget_show (spin);
+        gtk_box_pack_start (GTK_BOX (hbox), spin, FALSE, FALSE, 0);
+
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin), pager->rows);
+
+        g_signal_connect (spin, "value-changed", G_CALLBACK (rows_changed),
+                          pager);
+    }
+    else
+    {
+        GtkWidget *label = gtk_label_new ("1");
+
+        gtk_widget_show (label);
+        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    }
+}
+
 /*  Switcher panel control
  *  ----------------------
 */
@@ -267,6 +367,8 @@ create_pager_control (Control * control)
 G_MODULE_EXPORT void
 xfce_control_class_init (ControlClass * cc)
 {
+    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+
     cc->name = "pager";
     cc->caption = _("Graphical pager");
 
@@ -277,6 +379,10 @@ xfce_control_class_init (ControlClass * cc)
 
     cc->set_orientation = pager_set_orientation;
     cc->set_size = pager_set_size;
+
+    cc->read_config = pager_read_config;
+    cc->write_config = pager_write_config;
+    cc->create_options = pager_create_options;
 }
 
 XFCE_PLUGIN_CHECK_INIT
